EdgeDetection class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
detectEdge(String saveTo, {bool canUseGallery = true, String androidScanTitle = "Scanning", String? androidCropTitle, String androidCropBlackWhiteTitle = "Black White", String androidCropReset = "Reset", String? scanFrameBorderColor, String? scanFrameBodyColor, double? scanFrameThickness, bool autoCapture = false})
→ Future<bool>
-
Call this method to scan the object edge in live camera.
-
detectEdgeFromGallery(String saveTo, {String? androidCropTitle, String androidCropBlackWhiteTitle = "Black White", String androidCropReset = "Reset", String? scanFrameBorderColor, String? scanFrameBodyColor, double? scanFrameThickness})
→ Future<bool>
-
Call this method to scan the object edge from a gallery image.